@@ -18,8 +18,15 @@ hcf.aov <- function(x, ina, fc = TRUE) {
       Ft <- kappa * (1/kappa - 1/(5 * kappa^3)) * Ft
     } else if (p > 3)  Ft <- kappa * ( 1/kappa - (p - 3)/(4 * kappa^2) - (p - 3)/(4 * kappa^3) ) * Ft
   }
-  pvalue <- pf(Ft, (g - 1) * (p - 1), (n - g) * (p - 1), lower.tail = FALSE)
-  res <- c(Ft, pvalue, kappa)
-  names(res) <- c('test', 'p-value', 'kappa')
-  res
+
+  p.value <- pf(Ft, (g - 1) * (p - 1), (n - g) * (p - 1), lower.tail = FALSE)
+  statistic <- Ft  ;   names(statistic) <- "F-test statistic"
+  parameter <- c( (g - 1) * (p - 1), (n - g) * (p - 1) )     ;   names(parameter) <- c("df1", "df2")
+  alternative <- "At least one directional mean vector differs"
+  method <- "ANOVA for directional data using the high concentration test"
+  data.name <- c("data ", " groups")
+  result <- list( statistic = statistic, parameter = parameter, p.value = p.value,
+                  alternative = alternative, method = method, data.name = data.name )
+  class(result) <- "htest"
+  return(result)
 }
