@@ -1,7 +1,7 @@
 rgcpc <- function(n, mu = NULL, omega, g, rho, rads = TRUE) {
   if ( is.null(mu) ) {
     if ( !rads )  omega <- omega * pi/180
-    ksi <- cbind( cos(mu), sin(mu) )
+    ksi <- cbind( cos(omega), sin(omega) )
     mu <- g * ksi
   } else  ksi <- mu / sqrt( sum(mu^2) )
   sinv <- matrix( c( ksi[1]^2 + ksi[2]^2/rho, ksi[1] * ksi[2] * (1 - 1/rho), 
